==> v5.1.1.tar.gz: barker/bookie/src/app/tables/table-detail/table-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { Section } from '../../core/section';
import { Table } from '../../core/table';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { TableService } from '../table.service';

@Component({
  selector: 'app-table-detail',
  templateUrl: './table-detail.component.html',
  styleUrls: ['./table-detail.component.css'],
})
export class TableDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup;
  sections: Section[] = [];
  item: Table = new Table();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: TableService,
  ) {
    // Create form
    this.form = this.fb.group({
      name: '',
      seats: '',
      section: '',
      isActive: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Table; sections: Section[] };
      this.showItem(data.item);
      this.sections = data.sections;
    });
  }

  showItem(item: Table) {
    this.item = item;
    this.form.setValue({
      name: this.item.name,
      seats: this.item.seats,
      section: this.item.section.id ? this.item.section.id : '',
      isActive: this.item.isActive,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/tables');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/tables');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Account?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Table {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    this.item.seats = +formModel.seats;
    this.item.section.id = formModel.section;
    this.item.isActive = formModel.isActive;
    return this.item;
  }
}

==> v10.3.1.tar.gz: barker/bookie/src/app/tables/table-detail/table-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { Section } from '../../core/section';
import { Table } from '../../core/table';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { TableService } from '../table.service';

@Component({
  selector: 'app-table-detail',
  templateUrl: './table-detail.component.html',
  styleUrls: ['./table-detail.component.css'],
})
export class TableDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup;
  sections: Section[] = [];
  item: Table = new Table();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: TableService,
  ) {
    // Create form
    this.form = this.fb.group({
      name: '',
      seats: '',
      section: '',
      isActive: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Table; sections: Section[] };
      this.showItem(data.item);
      this.sections = data.sections;
    });
  }

  showItem(item: Table) {
    this.item = item;
    this.form.setValue({
      name: this.item.name,
      seats: this.item.seats,
      section: this.item.section ? this.item.section.id : '',
      isActive: this.item.isActive,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/tables');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/tables');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Account?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Table {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    this.item.seats = +formModel.seats;
    if (this.item.section === null || this.item.section === undefined) {
      this.item.section = new Section();
    }
    this.item.section.id = formModel.section;
    this.item.isActive = formModel.isActive;
    return this.item;
  }
}
